@@ -8,5 +8,5 @@ from ...models import OutstandingToken
 class Command(BaseCommand):
     help = "Flushes any expired tokens in the outstanding token list"
 
-    def handle(self, *args, **kwargs):
+    def handle(self, *args, **kwargs) -> None:
         OutstandingToken.objects.filter(expires_at__lte=aware_utcnow()).delete()
